Score gallery
=============

The following works were composed with the assistance of Abjad. The source code
for many of these scores is also available for pedagogical purposes.

..  hint::
    
    Click on any image to zoom in.


Demarest/Lloyd (2016)
`````````````````````

- For eleven percussionists
- Composed by `Josiah Wolf Oberholtzer`_.
- Written for the 50th anniversary of the Boston University Tanglewood
  Institute.
- Source available from https://github.com/josiah-wolf-oberholtzer/demarest/.

..  container:: table-row

    ..  thumbnail:: gallery/oberholtzer-demarest-page19.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 19 of Demarest/Lloyd,
                by Josiah Wolf Oberholtzer.
        
    ..  thumbnail:: gallery/oberholtzer-demarest-page28.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 28 of Demarest/Lloyd,
                by Josiah Wolf Oberholtzer.

Al-kitab al-khamr (2015)
````````````````````````

- For chamber orchestra.
- Composed by `Trevor Bača`_.
- Written for Ensemble Dal Niente.
- Source available from https://github.com/trevorbaca/khamr/.

..  raw:: html

    <p>
    <iframe width="100%" height="166" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/230978308&amp;color=ff5500&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false"></iframe>
    </p>

..  container:: table-row

    ..  thumbnail:: gallery/baca-khamr-page10.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 10 of Al-kitab al-khamr,
                by Trevor Bača.
        
    ..  thumbnail:: gallery/baca-khamr-page11.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 11 of Al-kitab al-khamr,
                by Trevor Bača.

Invisible Cities (iii): Ersilia (2015)
``````````````````````````````````````

- For chamber orchestra.
- Composed by `Josiah Wolf Oberholtzer`_.
- Written for Ensemble Dal Niente.
- Source available from https://github.com/josiah-wolf-oberholtzer/ersilia/.

..  raw:: html

    <p>
    <iframe width="100%" height="166" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/208631991&amp;color=ff5500&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false"></iframe>
    </p>

..  container:: table-row

    ..  thumbnail:: gallery/oberholtzer-ersilia-page9.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 9 of Invisible Cities (iii): Ersilia,
                by Josiah Wolf Oberholtzer.

    ..  thumbnail:: gallery/oberholtzer-ersilia-page10.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 10 of Invisible Cities (iii): Ersilia,
                by Josiah Wolf Oberholtzer.

Ins wasser eingeschrieben (2015)
````````````````````````````````

- For two violas.
- Composed by `Trevor Bača`_.
- Written for John Pickford Richards and Elizabeth Weisser.
- Source available from https://github.com/trevorbaca/ins-wasser/.

..  raw:: html

    <p>
    <iframe width="100%" height="166" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/230977561&amp;color=ff5500&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false"></iframe>
    </p>

..  container:: table-row

    ..  thumbnail:: gallery/baca-ins-wasser-page3.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 3 of Ins wasser eingeschrieben,
                by Trevor Bača.
        
    ..  thumbnail:: gallery/baca-ins-wasser-page4.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 4 of Ins wasser eingeschrieben,
                by Trevor Bača.


Invisible Cities (ii): Armilla (2015)
`````````````````````````````````````

- For two violas.
- Composed by `Josiah Wolf Oberholtzer`_.
- Written for John Pickford Richards and Elizabeth Weisser.
- Source available from https://github.com/josiah-wolf-oberholtzer/armilla/.

..  raw:: html

    <p>
    <iframe width="100%" height="166" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/206082457&amp;color=ff5500&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false"></iframe>
    </p>

..  container:: table-row

    ..  thumbnail:: gallery/oberholtzer-armilla-page8.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 8 of Invisible Cities (ii): Armilla,
                by Josiah Wolf Oberholtzer.

    ..  thumbnail:: gallery/oberholtzer-armilla-page9.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 9 of Invisible Cities (ii): Armilla,
                by Josiah Wolf Oberholtzer.

Refrain (2014)
``````````````

- For carillon.
- Composed by `Jeffrey Treviño`_.
- Written for Tiffany Ng.
- Source available from https://github.com/jefftrevino/refrain/.

..  raw:: html

    <p>
    <iframe width="100%" height="166" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/176190951&amp;color=ff5500&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false"></iframe>
    </p>

..  container:: table-row

    ..  thumbnail:: gallery/trevino-refrain-page1.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 1 of Refrain,
                by Jeffrey Treviño.

    ..  thumbnail:: gallery/trevino-refrain-page2.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 2 of Refrain,
                by Jeffrey Treviño.

Huitzil (2014)
``````````````

- For cello.
- Composed by `Trevor Bača`_.
- Written for Alan Toda-Ambaras.
- Source available from https://github.com/trevorbaca/huitzil/.

..  raw:: html

    <p>
    <iframe width="100%" height="166" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/243890076&amp;color=ff5500&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false"></iframe>
    </p>

..  container:: table-row

    ..  thumbnail:: gallery/baca-huitzil-page12.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 12 of Huitzil,
                by Trevor Bača.
        
    ..  thumbnail:: gallery/baca-huitzil-page13.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 13 of Huitzil,
                by Trevor Bača.

Invisible Cities (i): Zaira (2014)
``````````````````````````````````

- For chamber orchestra.
- Composed by `Josiah Wolf Oberholtzer`_.
- Written for Ensemble Mosaik.
- Source available from https://github.com/josiah-wolf-oberholtzer/zaira/.

..  raw:: html

    <p>
    <iframe width="100%" height="166" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/172956857&amp;color=ff5500&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false"></iframe>
    </p>

..  container:: table-row

    ..  thumbnail:: gallery/oberholtzer-zaira-page16.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 16 of Invisible Cities (i): Zaira,
                by Josiah Wolf Oberholtzer.

    ..  thumbnail:: gallery/oberholtzer-zaira-page17.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 17 of Invisible Cities (i): Zaira,
                by Josiah Wolf Oberholtzer.

Krummzeit (2014)
````````````````

- For seven players.
- Composed by `Trevor Bača`_.
- Written for Ensemble Mosaik.
- Source available from https://github.com/trevorbaca/krummzeit/.

..  raw:: html

    <p>
    <iframe width="100%" height="166" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/230976447&amp;color=ff5500&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false"></iframe>
    </p>

..  container:: table-row

    ..  thumbnail:: gallery/baca-krummzeit-page80.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 80 of Krummzeit,
                by Trevor Bača.
        
    ..  thumbnail:: gallery/baca-krummzeit-page81.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 81 of Krummzeit,
                by Trevor Bača.

Plague Water (2014)
```````````````````

- For baritone saxophone, electric guitar, piano and percussion.
- Composed by `Josiah Wolf Oberholtzer`_.
- Written for Ensemble Nikel.
- Source available from https://github.com/josiah-wolf-oberholtzer/plague-water/.

..  raw:: html

    <p>
    <iframe width="100%" height="166" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/145543310&amp;color=ff5500&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false"></iframe>
    </p>

..  container:: table-row

    ..  thumbnail:: gallery/oberholtzer-plague-water-page12.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 12 of Plague Water,
                by Josiah Wolf Oberholtzer.

    ..  thumbnail:: gallery/oberholtzer-plague-water-page13.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 13 of Plague Water,
                by Josiah Wolf Oberholtzer.

The World All Around (2012-13)
``````````````````````````````

- For Eb clarinet, harp, and prepared piano.
- Composed by `Jeffrey Treviño`_.
- Written for Wild Rumpus.
- Source available from https://github.com/jefftrevino/theWorldAllAround/.

..  raw:: html

    <p>
    <iframe width="100%" height="166" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/176197340&amp;color=ff5500&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false"></iframe>
    </p>

..  container:: table-row

    ..  thumbnail:: gallery/trevino-world-all-around-page1.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 1 of The World All Around,
                by Jeffrey Treviño.

    ..  thumbnail:: gallery/trevino-world-all-around-page2.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 2 of The World All Around,
                by Jeffrey Treviño.

Traiettorie inargentate (2013)
``````````````````````````````

- For cello.
- Composed by `Trevor Bača`_.
- Written for Séverine Ballon.
- Source available from https://github.com/trevorbaca/traiettorie/.

..  raw:: html

    <p>
    <iframe width="100%" height="166" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/230973560&amp;color=ff5500&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false"></iframe>
    </p>

..  container:: table-row

    ..  thumbnail:: gallery/baca-traiettorie-page6.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 6 of Traiettorie inargentate,
                by Trevor Bača.
        
    ..  thumbnail:: gallery/baca-traiettorie-page7.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 7 of Traiettorie inargentate,
                by Trevor Bača.

Cartography (2013)
``````````````````

- For bass flute, malletkat, oboe and trumpet.
- Composed by `Fredrik Wallberg`_.
- Written for Ensemble Chronophonie.

..  container:: table-row

    ..  thumbnail:: gallery/wallberg-cartography-bass-flute.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Bass flute part for Cartography,
                by Fredrik Wallberg.

Aurora (2011)
`````````````

- For string orchestra.
- Composed by `Josiah Wolf Oberholtzer`_.
- Written for Ensemble Kaleidoskop.
- Source available from https://github.com/josiah-wolf-oberholtzer/aurora/.

..  container:: table-row

    ..  thumbnail:: gallery/oberholtzer-aurora-page6.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 6 of Aurora,
                by Josiah Wolf Oberholtzer.
        
    ..  thumbnail:: gallery/oberholtzer-aurora-page7.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 7 of Aurora,
                by Josiah Wolf Oberholtzer.

L'archipel du corps (2011)
``````````````````````````

- For flute, guitar, accordion and percussion.
- Composed by `Trevor Bača`_.
- Written for Carin Levine, Jürgen Ruck, Stefan Hussong and Marta Klimasara.
- Source available from https://github.com/trevorbaca/archipel/.

..  raw:: html

    <p>
    <iframe width="100%" height="166" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/230779736&amp;color=ff5500&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false"></iframe>
    </p>

..  container:: table-row

    ..  thumbnail:: gallery/baca-archipel-page9.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 9 of L'archipel du corps,
                by Trevor Bača.
        
    ..  thumbnail:: gallery/baca-archipel-page10.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 10 of L'archipel du corps,
                by Trevor Bača.

L'imaginaire (2010)
```````````````````

- For accordion.
- Composed by `Trevor Bača`_.
- Written for Corrado Rojac.
- Source available from https://github.com/trevorbaca/imaginaire/.

..  raw:: html

    <p>
    <iframe width="100%" height="166" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/230778361&amp;color=ff5500&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false"></iframe>
    </p>

..  container:: table-row

    ..  thumbnail:: gallery/baca-imaginaire-page4.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 4 of L'imaginaire,
                by Trevor Bača.
        
    ..  thumbnail:: gallery/baca-imaginaire-page5.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 5 of L'imaginaire,
                by Trevor Bača.

Lagartija (2010)
````````````````

- For piccolo, percussion, violin and cello.
- Composed by `Josiah Wolf Oberholtzer`_.
- Written for White Rabbit.

..  container:: table-row

    ..  thumbnail:: gallery/oberholtzer-lagartija-page4.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 4 of Lagartija,
                by Josiah Wolf Oberholtzer.
        
    ..  thumbnail:: gallery/oberholtzer-lagartija-page5.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 5 of Lagartija,
                by Josiah Wolf Oberholtzer.

Mon seul désir (2009)
`````````````````````

- For flute, bass clarinet, violin and cello.
- Composed by `Trevor Bača`_.
- Written for Either/Or.
- Source available from https://github.com/trevorbaca/desir/.

..  raw:: html

    <p>
    <iframe width="100%" height="166" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/230777254&amp;color=ff5500&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false"></iframe>
    </p>

..  container:: table-row

    ..  thumbnail:: gallery/baca-desir-page14.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 14 of Mon seul désir,
                by Trevor Bača.
        
    ..  thumbnail:: gallery/baca-desir-page15.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 15 of Mon seul désir,
                by Trevor Bača.

Lidércfény (2008)
`````````````````

- For flute, violin and piano.
- Composed by `Trevor Bača`_.
- Written for Ensemble InFrequencies.
- Source available from https://github.com/trevorbaca/lidercfeny/.

..  raw:: html

    <p>
    <iframe width="100%" height="166" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/230683931&amp;color=ff5500&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false"></iframe>
    </p>

..  container:: table-row

    ..  thumbnail:: gallery/baca-lidercfeny-page22.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 22 of Lidércfény,
                by Trevor Bača.
        
    ..  thumbnail:: gallery/baca-lidercfeny-page23.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 23 of Lidércfény,
                by Trevor Bača.

Sekka (2007)
````````````

- For flute.
- Composed by `Trevor Bača`_.
- Written for Reiko Manabe.
- Source available from https://github.com/trevorbaca/sekka/.

..  raw:: html

    <p>
    <iframe width="100%" height="166" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/230676212&amp;color=ff5500&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false"></iframe>
    </p>

..  container:: table-row

    ..  thumbnail:: gallery/baca-sekka-page5.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 5 of Sekka,
                by Trevor Bača.
        
    ..  thumbnail:: gallery/baca-sekka-page6.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 6 of Sekka,
                by Trevor Bača.

Čáry (2006)
```````````

- For bass flute.
- Composed by `Trevor Bača`_.
- Written for Carin Levine.
- Source available from https://github.com/trevorbaca/cary/.

..  raw:: html

    <p>
    <iframe width="100%" height="166" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/230674427&amp;color=ff5500&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false"></iframe>
    </p>

..  container:: table-row

    ..  thumbnail:: gallery/baca-cary-page5.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 5 of Čáry,
                by Trevor Bača.
        
    ..  thumbnail:: gallery/baca-cary-page6.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 6 of Čáry,
                by Trevor Bača.

Poème Récursif (2005)
`````````````````````

- For 64 percussionists.
- Composed by `Trevor Bača`_.
- Source available from https://github.com/trevorbaca/recursif/.

..  container:: table-row

    ..  thumbnail:: gallery/baca-poeme-recursif-page3.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 3 of Poème Récursif,
                by Trevor Bača.
        
    ..  thumbnail:: gallery/baca-poeme-recursif-page4.png
        :class: table-cell thumbnail
        :group: gallery
        :title: Page 4 of Poème Récursif,
                by Trevor Bača.

..  _Fredrik Wallberg: http://quesebifurcan.github.io/music/
..  _Josiah Wolf Oberholtzer: http://josiahwolfoberholtzer.com/
..  _Trevor Bača: http://www.trevorbaca.com/
..  _Jeffrey Treviño: http://www.jeffreytrevino.com/
